@@ -6,6 +6,9 @@
 #define LOGIN_MODULE_H
 
 #include <QLabel>
+#include <QDBusInterface>
+#include <QDBusConnection>
+#include <QDBusPendingReply>
 
 #include "login_module_interface.h"
 
@@ -48,6 +51,7 @@ public:
     inline LoadType loadPluginType() const override { return  m_loadPluginType;}
     void setCallback(LoginCallBack *callback) override;
     std::string onMessage(const std::string &) override;
+    void reset() override;
 
 public Q_SLOTS:
     void slotIdentifyStatus(const QString &name, const int errorCode, const QString &msg);
@@ -78,6 +82,8 @@ private:
     AuthStatus m_authStatus;
     bool m_needSendAuthType;
     bool m_isLocked;
+    QDBusInterface*  m_login1SessionSelf;
+    bool m_IdentifyWithMultipleUserStarted;
 };
 
 } // namespace module
