@@ -37,6 +37,8 @@ int main(int argc, char *argv[])
     app = DApplication::globalApplication(argc, argv);
 #endif
 
+    // qt默认当最后一个窗口析构后，会自动退出程序，这里设置成false，防止插拔时，没有屏幕，导致进程退出
+    QApplication::setQuitOnLastWindowClosed(false);
     //解决Qt在Retina屏幕上图片模糊问题
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     app->setOrganizationName("deepin");
@@ -132,8 +134,16 @@ int main(int argc, char *argv[])
     shutdownAgent.setModel(model);
     DBusShutdownFrontService shutdownServices(&shutdownAgent);
 
-    auto createFrame = [&] (QScreen *screen, int count) -> QWidget* {
+    auto createFrame = [&] (QPointer<QScreen> screen, int count) -> QWidget* {
         LockFrame *lockFrame = new LockFrame(model);
+        // 创建Frame可能会花费数百毫秒，这个和机器性能有关，在此过程完成后，screen可能已经析构了
+        // 在wayland的环境插拔屏幕或者显卡驱动有问题时可能会出现此类问题
+        if (screen.isNull()) {
+            lockFrame->deleteLater();
+            lockFrame = nullptr;
+            qWarning() << "Screen was released when the frame was created ";
+            return nullptr;
+        }
         lockFrame->setScreen(screen, count <= 0);
         property_group->addObject(lockFrame);
         QObject::connect(lockFrame, &LockFrame::requestSwitchToUser, worker, &LockWorker::switchToUser);
