@@ -207,6 +207,7 @@ double getScaleFormConfig()
     //华为机型,从override配置中获取默认缩放比
     if (dconfig) {
         defaultScaleFactors = dconfig->value("defaultScaleFactors", 1.0).toDouble() ;
+        qDebug() << Q_FUNC_INFO <<"defaultScaleFactors :" << defaultScaleFactors;
         if(defaultScaleFactors < 1.0){
             defaultScaleFactors = 1.0;
         }
@@ -232,6 +233,9 @@ double getScaleFormConfig()
             QJsonObject Config = rootObj.value("Config").toObject();
             double scaleFactors = Config.value("ScaleFactors").toObject().value("ALL").toDouble();
             qDebug() << "scaleFactors :" << scaleFactors;
+            if(scaleFactors == 0.0) {
+                scaleFactors = defaultScaleFactors;
+            }
             return scaleFactors;
         } else {
             return defaultScaleFactors;
@@ -244,6 +248,7 @@ double getScaleFormConfig()
 
 static void set_auto_QT_SCALE_FACTOR() {
     const double ratio = IsWayland ? getScaleFormConfig() : get_scale_ratio();
+    qDebug() << Q_FUNC_INFO << "ratio" << ratio;
     if (ratio > 0.0) {
         setenv("QT_SCALE_FACTOR", QByteArray::number(ratio).constData(), 1);
     }
@@ -297,6 +302,8 @@ int main(int argc, char* argv[])
     }
 
     DApplication a(argc, argv);
+    // qt默认当最后一个窗口析构后，会自动退出程序，这里设置成false，防止插拔时，没有屏幕，导致进程退出
+    QApplication::setQuitOnLastWindowClosed(false);
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     qApp->setOrganizationName("deepin");
     qApp->setApplicationName("org.deepin.dde.lightdm-deepin-greeter");
@@ -374,6 +381,14 @@ int main(int argc, char* argv[])
 
     auto createFrame = [&](QPointer<QScreen> screen, int count) -> QWidget * {
         LoginWindow *loginFrame = new LoginWindow(model);
+        // 创建Frame可能会花费数百毫秒，这个和机器性能有关，在此过程完成后，screen可能已经析构了
+        // 在wayland的环境插拔屏幕或者显卡驱动有问题时可能会出现此类问题
+        if (screen.isNull()) {
+            loginFrame->deleteLater();
+            loginFrame = nullptr;
+            qWarning() << "Screen was released when the frame was created ";
+            return nullptr;
+        }
         loginFrame->setScreen(screen, count <= 0);
         property_group->addObject(loginFrame);
         QObject::connect(loginFrame, &LoginWindow::requestSwitchToUser, worker, &GreeterWorker::switchToUser);
@@ -384,11 +399,7 @@ int main(int argc, char* argv[])
         QObject::connect(loginFrame, &LoginWindow::requestEndAuthentication, worker, &GreeterWorker::endAuthentication);
         QObject::connect(loginFrame, &LoginWindow::authFinished, worker, &GreeterWorker::onAuthFinished);
         QObject::connect(worker, &GreeterWorker::requestUpdateBackground, loginFrame, &LoginWindow::updateBackground);
-        if (!IsWayland) {
-            loginFrame->show();
-        } else {
-            QObject::connect(worker, &GreeterWorker::showLoginWindow, loginFrame, &LoginWindow::setVisible);
-        }
+        loginFrame->setVisible(model->visible());
         return loginFrame;
     };
 
@@ -403,10 +414,7 @@ int main(int argc, char* argv[])
     checker.setOutputFormat(DAccessibilityChecker::FullFormat);
     checker.start();
 #endif
-
-    if (!IsWayland) {
-        model->setVisible(true);
-    }
+    model->setVisible(true);
 
     return a.exec();
 }
