@@ -1,27 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "lockframe.h"
 
@@ -102,13 +81,6 @@ LockFrame::LockFrame(SessionBaseModel *const model, QWidget *parent)
         //不管是待机还是唤醒均不响应电源按键信号
         m_enablePowerOffKey = false;
 
-        //唤醒1秒后才响应电源按键信号，避免待机唤醒时响应信号，将界面切换到关机选项
-        if (!isSleep) {
-            QTimer::singleShot(1000, this, [ = ] {
-                m_enablePowerOffKey = true;
-            });
-        }
-
         //待机时由锁屏提供假黑屏，唤醒时显示正常界面
         model->setIsBlackMode(isSleep);
         model->setVisible(true);
@@ -119,9 +91,19 @@ LockFrame::LockFrame(SessionBaseModel *const model, QWidget *parent)
                 QGSettings powerSettings("com.deepin.dde.power", QByteArray(), this);
                 if (!powerSettings.get("sleep-lock").toBool()) {
                     m_model->setVisible(false);
+                    return;
                 }
             }
         }
+
+        // 此处逻辑放到下面，唤醒不需要密码时，在性能差的机器上可能会在1秒后才收到电源事件，依就会响应电源事件
+        // 或者将延时改的更长
+        //唤醒1秒后才响应电源按键信号，避免待机唤醒时响应信号，将界面切换到关机选项
+        if (!isSleep) {
+            QTimer::singleShot(1000, this, [ = ] {
+                m_enablePowerOffKey = true;
+            });
+        }
     } );
 
     connect(model, &SessionBaseModel::authFinished, this, [this](bool success) {
@@ -232,8 +214,11 @@ bool LockFrame::handlePoweroffKey()
     qDebug() << "battery is: " << isBattery << "," << action;
     // 需要特殊处理：关机(0)和无任何操作(4)
     if (action == 0) {
-        //锁屏时或显示关机界面时，需要确认是否关机
-        emit m_model->onRequirePowerAction(SessionBaseModel::PowerAction::RequireShutdown, false);
+        // 待机刚唤醒一段时间内不响应电源按键事件
+        if (m_enablePowerOffKey) {
+            //锁屏时或显示关机界面时，需要确认是否关机
+            emit m_model->onRequirePowerAction(SessionBaseModel::PowerAction::RequireShutdown, false);
+        }
         return true;
     } else if (action == 4) {
         // 先检查当前是否允许响应电源按键
@@ -310,7 +295,13 @@ void LockFrame::cancelShutdownInhibit(bool hideFrame)
         setContentVisible(true);
     }
 
-    if (hideFrame) {
+    if (old_visible && hideFrame) {
+        // 从lock点的power btn，不能隐藏锁屏而进入桌面
+        if (!m_model->isPressedPowerBtnFromLock()) {
+            m_model->setVisible(false);
+        }
+
+        m_model->resetPowerBtnPressedFromLock();
         m_model->setCurrentModeState(SessionBaseModel::PasswordMode);
     }
 }
