@@ -12,9 +12,9 @@
 #include "sessionbasemodel.h"
 #include "sfa_widget.h"
 #include "shutdownwidget.h"
-#include "timewidget.h"
 #include "userframelist.h"
 #include "virtualkbinstance.h"
+#include "fullscreenbackground.h"
 
 #include <DDBusSender>
 
@@ -23,10 +23,13 @@
 
 using namespace dss;
 using namespace dss::module;
+DCORE_USE_NAMESPACE
 
 LockContent::LockContent(SessionBaseModel *const model, QWidget *parent)
     : SessionBaseWindow(parent)
     , m_model(model)
+    , m_controlWidget(nullptr)
+    , m_centerTopWidget(nullptr)
     , m_virtualKB(nullptr)
     , m_wmInter(new com::deepin::wm("com.deepin.wm", "/com/deepin/wm", QDBusConnection::sessionBus(), this))
     , m_sfaWidget(nullptr)
@@ -72,11 +75,8 @@ LockContent::LockContent(SessionBaseModel *const model, QWidget *parent)
 
 void LockContent::initUI()
 {
-    m_timeWidget = new TimeWidget();
-    m_timeWidget->setAccessibleName("TimeWidget");
-    setCenterTopWidget(m_timeWidget);
-    // 处理时间制跳转策略，获取到时间制再显示时间窗口
-    m_timeWidget->setVisible(false);
+    m_centerTopWidget = new CenterTopWidget(this);
+    setCenterTopWidget(m_centerTopWidget);
 
     m_shutdownFrame = new ShutdownWidget;
     m_shutdownFrame->setAccessibleName("ShutdownFrame");
@@ -232,7 +232,6 @@ void LockContent::onCurrentUserChanged(std::shared_ptr<User> user)
     //如果是锁屏就用系统语言，如果是登陆界面就用用户语言
     auto locale = qApp->applicationName() == "dde-lock" ? QLocale::system().name() : user->locale();
     m_logoWidget->updateLocale(locale);
-    m_timeWidget->updateLocale(locale);
 
     for (auto connect : m_currentUserConnects) {
         m_user.get()->disconnect(connect);
@@ -242,23 +241,11 @@ void LockContent::onCurrentUserChanged(std::shared_ptr<User> user)
 
     m_user = user;
 
-    m_timeWidget->set24HourFormat(user->isUse24HourFormat());
-    m_timeWidget->setWeekdayFormatType(user->weekdayFormat());
-    m_timeWidget->setShortDateFormat(user->shortDateFormat());
-    m_timeWidget->setShortTimeFormat(user->shortTimeFormat());
-
     m_currentUserConnects << connect(user.get(), &User::greeterBackgroundChanged, this, &LockContent::updateGreeterBackgroundPath, Qt::UniqueConnection)
-                          << connect(user.get(), &User::desktopBackgroundChanged, this, &LockContent::updateDesktopBackgroundPath, Qt::UniqueConnection)
-                          << connect(user.get(), &User::use24HourFormatChanged, this, &LockContent::updateTimeFormat, Qt::UniqueConnection)
-                          << connect(user.get(), &User::weekdayFormatChanged, m_timeWidget, &TimeWidget::setWeekdayFormatType)
-                          << connect(user.get(), &User::shortDateFormatChanged, m_timeWidget, &TimeWidget::setShortDateFormat)
-                          << connect(user.get(), &User::shortTimeFormatChanged, m_timeWidget, &TimeWidget::setShortTimeFormat);
+                          << connect(user.get(), &User::desktopBackgroundChanged, this, &LockContent::updateDesktopBackgroundPath, Qt::UniqueConnection);
 
     //TODO: refresh blur image
-    QTimer::singleShot(0, this, [ = ] {
-        updateTimeFormat(user->isUse24HourFormat());
-    });
-
+    m_centerTopWidget->setCurrentUser(user.get());
     m_logoWidget->updateLocale(locale);
 }
 
@@ -306,6 +293,9 @@ void LockContent::setMPRISEnable(const bool state)
 
 void LockContent::onNewConnection()
 {
+    // 重置密码界面显示前需要隐藏插件右键菜单，避免抢占键盘
+    Q_EMIT m_model->hidePluginMenu();
+
     // 重置密码程序启动连接成功锁屏界面才释放键盘，避免点击重置密码过程中使用快捷键切走锁屏
     if (window()->windowHandle() && window()->windowHandle()->setKeyboardGrabEnabled(false)) {
         qDebug() << "setKeyboardGrabEnabled(false) success！";
@@ -328,8 +318,19 @@ void LockContent::onNewConnection()
 
 void LockContent::onDisConnect()
 {
-    // 这种情况下不必强制要求可以抓取到键盘，因为可能是网络弹窗抓取了键盘
-    tryGrabKeyboard(false);
+    for (auto w : FullscreenBackground::frames()) {
+        if (w->contentVisible()) {
+            // 由于socket连接只会创建一个，断开连接的时候并不一定是socket对象所在LockContent对象处于显示的状态
+            // 需要找出当前显示LockContent，让它抓取键盘
+            // TODO 只创建一个LockContent的话则无需这样处理了
+            LockContent* lockContent = qobject_cast<LockContent*>(w->content());
+            if (lockContent) {
+                // 这种情况下不必强制要求可以抓取到键盘，因为可能是网络弹窗抓取了键盘
+                lockContent->tryGrabKeyboard(false);
+            }
+            break;
+        }
+    }
 }
 
 void LockContent::onStatusChanged(SessionBaseModel::ModeStatus status)
@@ -454,16 +455,6 @@ void LockContent::updateDesktopBackgroundPath(const QString &path)
     }
 }
 
-void LockContent::updateTimeFormat(bool use24)
-{
-    if (m_user != nullptr) {
-        auto locale = qApp->applicationName() == "dde-lock" ? QLocale::system().name() : m_user->locale();
-        m_timeWidget->updateLocale(locale);
-        m_timeWidget->set24HourFormat(use24);
-        m_timeWidget->setVisible(true);
-    }
-}
-
 void LockContent::toggleVirtualKB()
 {
     if (!m_virtualKB) {
