@@ -144,6 +144,9 @@ public:
 
     std::shared_ptr<User> json2User(const QString &userJson);
 
+    void setCurrentPowerBtnIndex(const int index);
+    inline int currentPowerBtnIndex() const { return m_currentPowerBntIndex;}
+
 signals:
     /* com.deepin.daemon.Accounts */
     void currentUserChanged(const std::shared_ptr<User>);
@@ -155,6 +158,7 @@ signals:
     void MFAFlagChanged(const bool);
     /* others */
     void visibleChanged(const bool);
+    void powerBtnIndexChanged(int index);
 
 public slots:
     /* com.deepin.daemon.Accounts */
@@ -213,6 +217,9 @@ signals:
     void authStateChanged(const int, const int, const QString &);
     void authTypeChanged(const int type);
 
+    // 关闭插件右键菜单信号
+    void hidePluginMenu();
+
 private:
     bool m_hasSwap;
     bool m_visible;
@@ -230,6 +237,7 @@ private:
     bool m_isUseWayland;
     bool m_pressedPowerBtnFromLock; // 从lock界面点的power按键
     int m_userListSize = 0;
+    int m_currentPowerBntIndex = -1;
     AppType m_appType;
     QList<std::shared_ptr<User>> m_userList;
     std::shared_ptr<User> m_currentUser;
