@@ -766,6 +766,7 @@ void SFAWidget::initCustomAuth()
 {
     qDebug() << Q_FUNC_INFO << "init custom auth";
     if (m_customAuth) {
+        m_customAuth->reset();
         return;
     }
 
@@ -864,7 +865,7 @@ void SFAWidget::checkAuthResult(const int type, const int state)
         }
 
         if (m_customAuth) {
-            m_customAuth->reset();
+            m_customAuth->resetAuth();
         }
     } else if (type != AT_All && state == AS_Success) {
         m_user->setLastAuthType(type);
@@ -906,9 +907,23 @@ void SFAWidget::replaceWidget(AuthModule *authModule)
         authModule->clearFocus();
     else
         authModule->setFocus();
-    m_lockButton->setEnabled(false);
     onRetryButtonVisibleChanged(false);
     updateBlurEffectGeometry();
+    if (m_currentAuthType == AT_PAM) {
+        if (m_singleAuth && m_singleAuth->lineEditText() == "") {
+            m_lockButton->setEnabled(false);
+        }
+    } else if (m_currentAuthType == AT_Ukey) {
+        if (m_ukeyAuth && m_ukeyAuth->lineEditText() == "") {
+            m_lockButton->setEnabled(false);
+        }
+    } else if (m_currentAuthType == AT_Password) {
+        if (m_passwordAuth && m_passwordAuth->lineEditText() == "") {
+            m_lockButton->setEnabled(false);
+        }
+    } else {
+        m_lockButton->setEnabled(false);
+    }
 }
 
 void SFAWidget::onRetryButtonVisibleChanged(bool visible)
@@ -1074,8 +1089,7 @@ void SFAWidget::onRequestChangeAuth(const int authType)
     qInfo() << Q_FUNC_INFO << "authType" << authType << "m_chooseAuthButtonBox->isEnabled()" << m_chooseAuthButtonBox->isEnabled()
                << "m_currentAuthType" << m_currentAuthType;
 
-    //当在S3/S4阶段时，会获取前一次认证的认证类型（不是AT_Custom），这时认证失败，也需要跳转到指纹认证
-    if(!m_chooseAuthButtonBox->isEnabled() || (m_currentAuthType != AT_Custom && m_model->appType() == AuthCommon::AppType::Login)) {
+    if (!m_chooseAuthButtonBox->isEnabled()) {
         return;
     }
 
