@@ -21,6 +21,7 @@ DCORE_USE_NAMESPACE
 ShutdownWidget::ShutdownWidget(QWidget *parent)
     : QFrame(parent)
     , m_index(-1)
+    , m_status(SessionBaseModel::NoStatus)
     , m_model(nullptr)
     , m_systemMonitor(nullptr)
     , m_switchosInterface(new HuaWeiSwitchOSInterface("com.huawei", "/com/huawei/switchos", QDBusConnection::sessionBus(), this))
@@ -35,13 +36,6 @@ ShutdownWidget::ShutdownWidget(QWidget *parent)
     onEnable("systemSuspend", enableState(GSettingWatcher::instance()->getStatus("systemSuspend")));
     onEnable("systemHibernate", enableState(GSettingWatcher::instance()->getStatus("systemHibernate")));
     onEnable("systemLock", enableState(GSettingWatcher::instance()->getStatus("systemLock")));
-
-    std::function<void (QVariant)> function = std::bind(&ShutdownWidget::onOtherPageChanged, this, std::placeholders::_1);
-    int index = m_frameDataBind->registerFunction("ShutdownWidget", function);
-
-    connect(this, &ShutdownWidget::destroyed, this, [this, index] {
-        m_frameDataBind->unRegisterFunction("ShutdownWidget", index);
-    });
     installEventFilter(this);
 }
 
@@ -54,6 +48,7 @@ ShutdownWidget::~ShutdownWidget()
 
 void ShutdownWidget::initConnect()
 {
+    connect(m_model, &SessionBaseModel::powerBtnIndexChanged, this, &ShutdownWidget::onPowerBtnIndexChanged);
     connect(m_requireRestartButton, &RoundItemButton::clicked, this, [ = ] {
         m_currentSelectedBtn = m_requireRestartButton;
         onRequirePowerAction(SessionBaseModel::PowerAction::RequireRestart, false);
@@ -132,14 +127,18 @@ void ShutdownWidget::onEnable(const QString &gsettingsName, bool enable)
     }
 }
 
-void ShutdownWidget::onOtherPageChanged(const QVariant &value)
+void ShutdownWidget::onPowerBtnIndexChanged(const int index)
 {
-    m_index = value.toInt();
+    if (m_index == index)
+        return;
 
     for (auto it = m_btnList.constBegin(); it != m_btnList.constEnd(); ++it) {
         (*it)->updateState(RoundItemButton::Normal);
     }
 
+    if (m_index < 0)
+        return;
+
     m_currentSelectedBtn = m_btnList.at(m_index);
     m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 }
@@ -151,7 +150,8 @@ void ShutdownWidget::enterKeyPushed()
         return;
     }
 
-    if (!m_currentSelectedBtn->isEnabled())
+    // 在按回车键时，若m_currentSelectedBtn不存在，则退出
+    if (!m_currentSelectedBtn || !m_currentSelectedBtn->isEnabled())
         return;
 
     if (m_currentSelectedBtn == m_requireShutdownButton)
@@ -340,11 +340,11 @@ void ShutdownWidget::leftKeySwitch()
         }
     }
 
+    // 选择按钮变化时保存下标并同步给另一个屏幕上的界面
+    m_model->setCurrentPowerBtnIndex(m_index);
     m_currentSelectedBtn = m_btnList.at(m_index);
     m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 
-    m_frameDataBind->updateValue("ShutdownWidget", m_index);
-
     if (m_systemMonitor && m_systemMonitor->isVisible()) {
         m_systemMonitor->setState(SystemMonitor::Leave);
     }
@@ -369,11 +369,11 @@ void ShutdownWidget::rightKeySwitch()
         }
     }
 
+    // 选择按钮变化时保存下标并同步给另一个屏幕上的界面
+    m_model->setCurrentPowerBtnIndex(m_index);
     m_currentSelectedBtn = m_btnList.at(m_index);
     m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 
-    m_frameDataBind->updateValue("ShutdownWidget", m_index);
-
     if (m_systemMonitor && m_systemMonitor->isVisible()) {
         m_systemMonitor->setState(SystemMonitor::Leave);
     }
@@ -381,8 +381,10 @@ void ShutdownWidget::rightKeySwitch()
 
 void ShutdownWidget::onStatusChanged(SessionBaseModel::ModeStatus status)
 {
+    // 显示方式变化时初始化按钮是否可见和默认选择的按钮，关机界面默认为待机  锁屏界面为关机
+    m_status = status;
     RoundItemButton *roundItemButton;
-    if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
+    if (m_status == SessionBaseModel::ModeStatus::ShutDownMode) {
         m_requireLockButton->setVisible(GSettingWatcher::instance()->getStatus("systemLock") != "Hiden");
         m_requireSwitchUserBtn->setVisible(m_switchUserEnable);
         if (m_requireSwitchSystemBtn) {
@@ -400,17 +402,21 @@ void ShutdownWidget::onStatusChanged(SessionBaseModel::ModeStatus status)
         roundItemButton = m_requireShutdownButton;
     }
 
-    // 同步显示另一个显示器关机界面上当前选中的按钮，若还未同步则显示关机或锁屏默认按钮
-    if (m_index >= 0 && m_index < m_btnList.size()) {
-        RoundItemButton * tmpBtn = m_btnList.at(m_index);
-        if (tmpBtn && tmpBtn->isVisible()) {
-            roundItemButton = tmpBtn;
-        }
+    // 读取保存的按钮下标，同步选择的按钮
+    int tmpIndex = m_model->currentPowerBtnIndex();
+    if (m_index != tmpIndex) {
+        m_index = tmpIndex;
     }
 
-    int index =  m_btnList.indexOf(roundItemButton);
-    roundItemButton->updateState(RoundItemButton::Checked);
-    m_frameDataBind->updateValue("ShutdownWidget", index);
+    // 如果没有选择过按钮，则选择默认按钮
+    if (m_index < 0) {
+        m_index = m_btnList.indexOf(roundItemButton);
+    }
+
+    // 选择按钮变化时保存下标并同步给另一个屏幕上的界面
+    m_model->setCurrentPowerBtnIndex(m_index);
+    m_currentSelectedBtn = m_btnList.at(m_index);
+    m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 
     if (m_systemMonitor) {
         m_systemMonitor->setVisible(status == SessionBaseModel::ModeStatus::ShutDownMode);
@@ -533,21 +539,23 @@ bool ShutdownWidget::event(QEvent *e)
     }
 
     if (e->type() == QEvent::FocusIn) {
-        if (m_index < 0 || m_index >= m_btnList.size()) {
-            m_index = 0;
+        if (m_index >= 0 && m_index < m_btnList.size()) {
+            m_model->setCurrentPowerBtnIndex(m_index);
+            m_currentSelectedBtn =  m_btnList.at(m_index);
+            m_currentSelectedBtn->updateState(RoundItemButton::Checked);
         }
-        m_frameDataBind->updateValue("ShutdownWidget", m_index);
-        m_btnList.at(m_index)->updateState(RoundItemButton::Checked);
     } else if (e->type() == QEvent::FocusOut) {
-        if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
-            // 丢失焦点后，获取焦点。双屏拔掉一个显示器会导致焦点丢失
-            if (this->isVisible())
-                this->activateWindow();
-        } else {
-            if (m_index < 0 || m_index >= m_btnList.size()) {
-                m_index = 0;
+        // 界面在显示状态时丢失焦点后，需要重新获取焦点。双屏拔掉一个显示器会导致焦点丢失
+        if (this->isVisible()) {
+            this->activateWindow();
+
+            // 显示并点击屏幕键盘时，此时会失去焦点，但是还需要保持当前按钮选择状态，此时m_index选择的按钮是有效的。
+            // 如果是界面隐藏导致的失去焦点，m_index是无效的，不需要保持当前按钮选择状态
+            if (m_index >= 0 && m_index < m_btnList.size()) {
+                m_model->setCurrentPowerBtnIndex(m_index);
+                m_currentSelectedBtn = m_btnList.at(m_index);
+                m_currentSelectedBtn->updateState(RoundItemButton::Normal);
             }
-            m_btnList.at(m_index)->updateState(RoundItemButton::Normal);
         }
     }
 
@@ -563,6 +571,13 @@ void ShutdownWidget::showEvent(QShowEvent *event)
 void ShutdownWidget::hideEvent(QHideEvent *event)
 {
     m_index = -1;
+    m_currentSelectedBtn = nullptr;
+    // 多屏间移动鼠标时其中一个屏幕的界面会隐藏，此时需要根据条件是否初始化按钮下标
+    // 退出锁屏关机界面时，初始化当前按钮下标为-1
+    // 切换显示方式时，初始化当前按钮下标为-1
+    if (!m_model->visible() || m_status != m_model->currentModeState()) {
+        m_model->setCurrentPowerBtnIndex(-1);
+    }
     QFrame::hideEvent(event);
 }
 
